/* Project name:
     CF_Detect (Demonstration of Compact Flash Library usage)
 * Copyright:
     (c) MikroElektronika, 2010.
 * Revision History
     2006:
     - Initial release;
     20101130(TL):
     - Adapted for PRO compilers;
 * Description:
     This project demonstrates usage of the Compact Flash Library routines,
     to detect CF (Compact Flash Card) storage media.
 * Test configuration:
     
     MCU:             ATMega128
                      http://www.atmel.com/dyn/resources/prod_documents/doc2467.pdf
     Dev.Board:       BIGAVR6
                      http://www.mikroe.com/eng/products/view/322/bigavr6-development-system/
     Oscillator:      HS, 08.00000 MHz
     Ext. Modules:    ac:Compact_Flash_Board
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
                      ac:LCD_2x16
                      http://www.mikroe.com/eng/products/view/277/various-components/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
         
 * NOTES:
     - PORTB (CF ctrl), PORTD (CF Data), LEDs = OFF
*/

// LCD module connections
sbit LCD_RS at PORTC2_bit;
sbit LCD_EN at PORTC3_bit;
sbit LCD_D4 at PORTC4_bit;
sbit LCD_D5 at PORTC5_bit;
sbit LCD_D6 at PORTC6_bit;
sbit LCD_D7 at PORTC7_bit;

sbit LCD_RS_Direction at DDC2_bit;
sbit LCD_EN_Direction at DDC3_bit;
sbit LCD_D4_Direction at DDC4_bit;
sbit LCD_D5_Direction at DDC5_bit;
sbit LCD_D6_Direction at DDC6_bit;
sbit LCD_D7_Direction at DDC7_bit;
// End LCD module connections

// set compact flash pinout
char Cf_Data_Port at PORTD;
char Cf_Data_Port_Direction at DDRD;

sbit CF_RDY at PINB7_bit;
sbit CF_WE  at PORTB6_bit;
sbit CF_OE  at PORTB5_bit;
sbit CF_CD1 at PINB4_bit;
sbit CF_CE1 at PORTB3_bit;
sbit CF_A2  at PORTB2_bit;
sbit CF_A1  at PORTB1_bit;
sbit CF_A0  at PORTB0_bit;

sbit CF_RDY_direction at DDB7_bit;
sbit CF_WE_direction  at DDB6_bit;
sbit CF_OE_direction  at DDB5_bit;
sbit CF_CD1_direction at DDB4_bit;
sbit CF_CE1_direction at DDB3_bit;
sbit CF_A2_direction  at DDB2_bit;
sbit CF_A1_direction  at DDB1_bit;
sbit CF_A0_direction  at DDB0_bit;
// end of cf pinout

void main() {
  Lcd_Init();
  Lcd_Cmd(_LCD_CLEAR);
  Lcd_Cmd(_LCD_CURSOR_OFF);
  Lcd_Out(1,1,"Compact Flash");

  Cf_Init();    // Initialize CF ports
  while (1) {
     if (Cf_Detect())
        Lcd_Out(2,5,"Detected");
     else
        Lcd_Out(2,1,"Not Detected");

       Delay_ms(1000);
  }
}