/* Project name:
     CF_Read (Demonstration of Compact Flash Library usage)
 * Copyright:
     (c) MikroElektronika, 2010.
 * Revision History
     2006:
     - Initial release;
     20101130(TL):
     - Adapted for PRO compilers;
 * Description:
     This project demonstrates usage of the Compact Flash Library routines,
     to access and raed from the CF (Compact Flash Card) storage media.
     Upon initialization, this example reads some data from the CF card.
     The reading progress can be monitored on portC LEDs.
 * Test configuration:
     
     MCU:             ATMega128
                      http://www.atmel.kr/dyn/resources/prod_documents/doc2467.pdf
     Dev.Board:       BIGAVR6
                      http://www.mikroe.com/eng/products/view/322/bigavr6-development-system/
     Oscillator:      HS, 08.0000 MHz
     Ext. Modules:    ac:Compact_Flash_Board
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/eng/products/view/228/mikroc-pro-for-avr/
         
 * NOTES:
     - PORTB (CF ctrl), PORTD (CF Data), LEDs = OFF
     - PORTC LEDs switch = ON (for monitoring progress)
*/


// set compact flash pinout
char Cf_Data_Port at PORTD;
char Cf_Data_Port_Direction at DDRD;

sbit CF_RDY at PINB7_bit;
sbit CF_WE  at PORTB6_bit;
sbit CF_OE  at PORTB5_bit;
sbit CF_CD1 at PINB4_bit;
sbit CF_CE1 at PORTB3_bit;
sbit CF_A2  at PORTB2_bit;
sbit CF_A1  at PORTB1_bit;
sbit CF_A0  at PORTB0_bit;

sbit CF_RDY_direction at DDB7_bit;
sbit CF_WE_direction  at DDB6_bit;
sbit CF_OE_direction  at DDB5_bit;
sbit CF_CD1_direction at DDB4_bit;
sbit CF_CE1_direction at DDB3_bit;
sbit CF_A2_direction  at DDB2_bit;
sbit CF_A1_direction  at DDB1_bit;
sbit CF_A0_direction  at DDB0_bit;
// end of cf pinout


unsigned i;
char error;

void main() {
  PORTC = 0xFF;               // For monitoring progress
  DDRC = 0xFF;
  Delay_ms(1000);

  Cf_Init();                  // Initialize CF ports
  while (!Cf_Detect()) ;      // Loop until CF card is initialized

  PORTC = 0x0F;
  Delay_ms(1000);

  error = 0;
  Cf_Read_Init(590, 1);       // Initialize CF read from sector address 590

  for (i = 0; i < 200; i++) {
     PORTC = Cf_Read_Byte();  // Read byte from CF card
     Delay_ms(10);
     if (PORTC != i) error =1;
  }

  PORTC = 0xFF;
  Delay_ms(1000);
  PORTC = error;
}