/* Project name:
     CF_Write (Demonstration of Compact Flash Library usage)
 * Copyright:
     (c) MikroElektronika, 2010.
 * Revision History
     2006:
     - Initial release;
     20101130(TL);
     - Adapted for PRO compilers
 * Description:
     This project demonstrates usage of the Compact Flash Library routines,
     accessing and writing to the CF (Compact Flash Card) storage media.
     Example writes 256x2 bytes of adc_conversion_result to CF card at sector 590
     The writing progress can be monitored on portC LEDs.

 * Test configuration:

     MCU:             PIC18F4520
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39631E.pdf
     Dev.Board:       EasyPIC6
                      http://www.mikroe.com/eng/products/view/297/easypic6-development-system/
     Oscillator:      HS, 8.000 MHz
     Ext. Modules:    ac:Compact_Flash_Board
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/eng/products/view/7/mikroc-pro-for-pic/
         
 * NOTES:
     PORTB (CF ctrl), PORTD (CF Data), LEDs = OFF
     J15 jumper on RA2 position (bring potentiometer output to RA2 pin)
     PORTC LEDs switch = ON (for monitoring progress)
     PORTA pull-up / down and LEDs = Switched OFF
*/

#include <built_in.h>

// set compact flash pinout
char Cf_Data_Port at PORTD;

sbit CF_RDY at RB7_bit;
sbit CF_WE  at LATB6_bit;  // for writing to output pin always use latch (PIC18 family)
sbit CF_OE  at LATB5_bit;  // for writing to output pin always use latch (PIC18 family)
sbit CF_CD1 at RB4_bit;
sbit CF_CE1 at LATB3_bit;  // for writing to output pin always use latch (PIC18 family)
sbit CF_A2  at LATB2_bit;  // for writing to output pin always use latch (PIC18 family)
sbit CF_A1  at LATB1_bit;  // for writing to output pin always use latch (PIC18 family)
sbit CF_A0  at LATB0_bit;  // for writing to output pin always use latch (PIC18 family)

sbit CF_RDY_direction at TRISB7_bit;
sbit CF_WE_direction  at TRISB6_bit;
sbit CF_OE_direction  at TRISB5_bit;
sbit CF_CD1_direction at TRISB4_bit;
sbit CF_CE1_direction at TRISB3_bit;
sbit CF_A2_direction  at TRISB2_bit;
sbit CF_A1_direction  at TRISB1_bit;
sbit CF_A0_direction  at TRISB0_bit;
// end of cf pinout

unsigned i;
unsigned int temp_adc;

void main() {
  ADCON1 = 0x80;                     // Configure analog inputs and Vref
  TRISA  = 0xFF;                     // PORTA is input

  PORTC = 0xFF;                      // For monitoring progress
  TRISC = 0;
  Delay_ms(1000);

  Cf_Init();                         // Initialize CF ports
  while (!Cf_Detect());              // Loop until CF card is initialized

  PORTC = 0x0F;
  Delay_ms(1000);

  Cf_Write_Init(590, 1);             // Initialize CF write at sector address 590

  // Write 512 bytes to sector (590)
  for(i=0 ; i<256 ; i++)  {
    PORTC = i;
    temp_adc    = ADC_Read(2);       // Get results of AD conversion from channel2
    Cf_Write_Byte(Hi(temp_adc));     // Put higher 8 bits to buffer
    Cf_Write_Byte(Lo(temp_adc));     // Put lower 8 bits to buffer
    Delay_ms(20);
  }
}