/* Project name:
     CF_Detect (Demonstration of Compact Flash Library usage)
 * Copyright:
     (c) MikroElektronika, 2010.
 * Revision History
     2006:
     - Initial release;
     20101130(TL):
     - Adapted for PRO compilers;
 * Description:
     This project demonstrates usage of the Compact Flash Library routines,
     to detect CF (Compact Flash Card) storage media.
 * Test configuration:
     MCU:             PIC18F4520
                      http://ww1.microchip.com/downloads/en/DeviceDoc/39631E.pdf
     Dev.Board:       EasyPIC6
                      http://www.mikroe.com/eng/products/view/297/easypic6-development-system/
     Oscillator:      HS-PLL 4x, 32.0000 MHz
     Ext. Modules:    ac:Compact_Flash_Board
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
                      ac:LCD_2x16
                      http://www.mikroe.com/eng/products/view/277/various-components/
     SW:              mikroC PRO for PIC
                      http://www.mikroe.com/eng/products/view/7/mikroc-pro-for-pic/
        
 * NOTES:
     - PORTC (CF ctrl), PORTD (CF Data), LEDs = Off
     - This example works on PIC18 MCUs only.
*/
// LCD module connections
sbit LCD_RS at LATB4_bit;
sbit LCD_EN at LATB5_bit;
sbit LCD_D4 at LATB0_bit;
sbit LCD_D5 at LATB1_bit;
sbit LCD_D6 at LATB2_bit;
sbit LCD_D7 at LATB3_bit;

sbit LCD_RS_Direction at TRISB4_bit;
sbit LCD_EN_Direction at TRISB5_bit;
sbit LCD_D4_Direction at TRISB0_bit;
sbit LCD_D5_Direction at TRISB1_bit;
sbit LCD_D6_Direction at TRISB2_bit;
sbit LCD_D7_Direction at TRISB3_bit;
// End LCD module connections

// set compact flash pinout
char Cf_Data_Port at PORTD;

sbit CF_RDY at RC7_bit;
sbit CF_WE  at LATC6_bit;  // for writing to output pin always use latch (PIC18 family)
sbit CF_OE  at LATC5_bit;  // for writing to output pin always use latch (PIC18 family)
sbit CF_CD1 at RC4_bit;
sbit CF_CE1 at LATC3_bit;  // for writing to output pin always use latch (PIC18 family)
sbit CF_A2  at LATC2_bit;  // for writing to output pin always use latch (PIC18 family)
sbit CF_A1  at LATC1_bit;  // for writing to output pin always use latch (PIC18 family)
sbit CF_A0  at LATC0_bit;  // for writing to output pin always use latch (PIC18 family)

sbit CF_RDY_direction at TRISC7_bit;
sbit CF_WE_direction  at TRISC6_bit;
sbit CF_OE_direction  at TRISC5_bit;
sbit CF_CD1_direction at TRISC4_bit;
sbit CF_CE1_direction at TRISC3_bit;
sbit CF_A2_direction  at TRISC2_bit;
sbit CF_A1_direction  at TRISC1_bit;
sbit CF_A0_direction  at TRISC0_bit;
// end of cf pinout

void main() {
  Lcd_Init();
  Lcd_Cmd(_LCD_CLEAR);
  Lcd_Cmd(_LCD_CURSOR_OFF);
  Lcd_Out(1,1,"Compact Flash");

  Cf_Init();    // Initialize CF ports
  while (1) {
     if (Cf_Detect())
        Lcd_Out(2,5,"Detected");
     else
        Lcd_Out(2,1,"Not Detected");

       Delay_ms(1000);
  }
}