/* Project name:
     CF_Detect (Demonstration of Compact Flash Library usage)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History
     20110303 (TL):
     - Initial release;
 * Description:
     This project demonstrates usage of the Compact Flash Library routines,
     to detect CF (Compact Flash Card) storage media.
 * Test configuration:
     MCU:             P32MX460F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61143G.pdf
     Dev.Board:       LV32MX v6
                      http://www.mikroe.com/eng/products/view/462/lv-32mx-v6-development-system/
     Oscillator:      XT-PLL, 80.000MHz
     Ext. Modules:    mE ac:Compact_Flash_Board on PORTD(Control) and PORTE(Data)
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/eng/categories/view/89/pic32-compilers/
 * NOTES:
     - Switch ON UART1 pins Rx1 (RF2) and Tx1 (RF8) at SW15.
     - This example does NOT cover writing/reading of FILES on the CF media. This
       topic is covered in CF_FAT16 examples.
     - For some CF cards external power supply may be required.
*/

// set compact flash pinout
char Cf_Data_Port at PORTE;

sbit CF_RDY at RD7_bit;
sbit CF_WE  at LATD6_bit;  // for writing to output pin always use latch
sbit CF_OE  at LATD5_bit;  // for writing to output pin always use latch
sbit CF_CD1 at RD4_bit;
sbit CF_CE1 at LATD3_bit;  // for writing to output pin always use latch
sbit CF_A2  at LATD2_bit;  // for writing to output pin always use latch
sbit CF_A1  at LATD1_bit;  // for writing to output pin always use latch
sbit CF_A0  at LATD0_bit;  // for writing to output pin always use latch

sbit CF_RDY_direction at TRISD7_bit;
sbit CF_WE_direction  at TRISD6_bit;
sbit CF_OE_direction  at TRISD5_bit;
sbit CF_CD1_direction at TRISD4_bit;
sbit CF_CE1_direction at TRISD3_bit;
sbit CF_A2_direction  at TRISD2_bit;
sbit CF_A1_direction  at TRISD1_bit;
sbit CF_A0_direction  at TRISD0_bit;
// end of cf pinout

void main() {
  AD1PCFG = 0xFFFF;        // disable A/D inputs

  // Initialize UART1 module
  UART1_Init(56000);
  Delay_ms(100);
 
  UART1_Write_Text("Start");
  UART1_Write(13);
  UART1_Write(10);

  Cf_Init();               // initialize CF
  Delay_ms(100);

  while (1) {
     // Checks for presence of CF card by reading the chip detect pin.
     if (Cf_Detect()){
            UART1_Write_Text("Detected");      // sends text via UART.
            UART1_Write(13);
            UART1_Write(10);
          }
          else{
            UART1_Write_Text("Not Detected");  // sends text via UART.
            UART1_Write(13);
            UART1_Write(10);
            }
       Delay_ms(1000);
  }
}