/* Project name:
     Cf_Fat16_Read (Demonstration of usage of Cf_Fat16 library)
 * Copyright:
     (c) Mikroelektronika, 2011.
 * Revision History:
     20110303 (TL):
       - initial release;
 * Description:
     This project consists of block that demonstrate one of the aspects of
     usage of the Cf_Fat16 library. Here is:
     - Reading file contents;
 * Test configuration:
     MCU:             P32MX460F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61143G.pdf
     Dev.Board:       LV32MX v6
                      http://www.mikroe.com/eng/products/view/462/lv-32mx-v6-development-system/
     Oscillator:      XT-PLL, 80.000MHz
     Ext. Modules:    mE  ac:Compact_Flash_Board on PORTD(Control) and PORTE(Data)
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/eng/categories/view/89/pic32-compilers/
 * NOTES:
     - Make sure that CF card is properly formatted (to FAT16 or just FAT)
       before testing it on this example.
     - Connect the RS232 cable and turn ON UARTA switches at SW15. (board specific).
     - This example expects CF card to be inserted before reset, otherwise,
       the FAT_ERROR message is displayed.
     - For some CF cards external power supply may be required.
 */

// set compact flash pinout
char Cf_Data_Port at PORTE;

sbit CF_RDY at RD7_bit;
sbit CF_WE  at LATD6_bit;  // for writing to output pin always use latch
sbit CF_OE  at LATD5_bit;  // for writing to output pin always use latch
sbit CF_CD1 at RD4_bit;
sbit CF_CE1 at LATD3_bit;  // for writing to output pin always use latch
sbit CF_A2  at LATD2_bit;  // for writing to output pin always use latch
sbit CF_A1  at LATD1_bit;  // for writing to output pin always use latch
sbit CF_A0  at LATD0_bit;  // for writing to output pin always use latch

sbit CF_RDY_direction at TRISD7_bit;
sbit CF_WE_direction  at TRISD6_bit;
sbit CF_OE_direction  at TRISD5_bit;
sbit CF_CD1_direction at TRISD4_bit;
sbit CF_CE1_direction at TRISD3_bit;
sbit CF_A2_direction  at TRISD2_bit;
sbit CF_A1_direction  at TRISD1_bit;
sbit CF_A0_direction  at TRISD0_bit;
// end of cf pinout

const LINE_LEN = 39;
char err_txt[20]       = "FAT16 not found";
char file_contents[LINE_LEN] = "XX CF FAT16 library by Anton Rieckert\n";
char           filename[14] = "MIKRO00x.TXT";          // File names
unsigned short loop, loop2;
unsigned long  i, size;
char           Buffer[512];

// UART1 write text and new line (carriage return + line feed)
void UART1_Write_Line(char *uart_text) {
  UART1_Write_Text(uart_text);
  UART1_Write(13);
  UART1_Write(10);
}

// Opens an existing file, reads data from it and puts it to UART
void M_Open_File_Read() {
  char character;

  filename[7] = 'B';
  Cf_Fat_Assign(&filename, 0);
  Cf_Fat_Reset(&size);             // To read file, procedure returns size of file
  for (i = 1; i <= size; i++) {
    Cf_Fat_Read(&character);
    UART1_Write(character);        // Write data to UART
  }
}

void main() {
  #define COMPLETE_EXAMPLE            // comment this line to make simpler/smaller example
  AD1PCFG = 0xFFFF;                   // disable A/D inputs

  // Initialize UART1 module
  UART1_Init(56000);
  Delay_ms(10);

  UART1_Write_Line("MCU-Started");    // MCU present report

  // use fat16 quick format instead of init routine if a formatting is needed
  if (Cf_Fat_Init() == 0) {
    Delay_ms(2000);                   // wait for a while until the card is stabilized
                                      //   period depends on used CF card
    //--- Test start
    UART1_Write_Line("Test Start.");
    //--- Test routines. Uncomment them one-by-one to test certain features
    #ifdef COMPLETE_EXAMPLE
      M_Open_File_Read();
    #endif
    UART1_Write_Line("Test End.");
  }
  else {
    UART1_Write_Line(err_txt); // Note: Cf_Fat_Init tries to initialize a card more than once.
                               //       If card is not present, initialization may last longer (depending on clock speed)
    Delay_ms(2000);
    UART1_Write_Line("Test End.");
  }
}