/* Project name:
     CF_Read (Demonstration of Compact Flash Library usage)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History
     20110304(TL):
     - Initial release;
 * Description:
     This project demonstrates usage of the Compact Flash Library routines,
     to access and raed from the CF (Compact Flash Card) storage media.
     Upon initialization, this example reads some data from the CF card.
     The reading progress can be monitored on portC LEDs.
 * Test configuration:
    
     MCU:             P32MX460F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61143G.pdf
     Dev.Board:       LV32MX v6
                      http://www.mikroe.com/eng/products/view/462/lv-32mx-v6-development-system/
     Oscillator:      XT-PLL, 80.000MHz
     Ext. Modules:    mE  ac:Compact_Flash_Board on PORTD(Control) and PORTE(Data)
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/eng/products/view/623/mikroc-pro-for-pic32/

 * NOTES:
     - PortD(CF ctrl), PortE(CF Data), LEDs = OFF
     - PORTB LEDs switch = ON (for monitoring progress)
*/

// set compact flash pinout
char Cf_Data_Port at PORTE;

sbit CF_RDY at RD7_bit;
sbit CF_WE  at LATD6_bit;  // for writing to output pin always use latch
sbit CF_OE  at LATD5_bit;  // for writing to output pin always use latch
sbit CF_CD1 at RD4_bit;
sbit CF_CE1 at LATD3_bit;  // for writing to output pin always use latch
sbit CF_A2  at LATD2_bit;  // for writing to output pin always use latch
sbit CF_A1  at LATD1_bit;  // for writing to output pin always use latch
sbit CF_A0  at LATD0_bit;  // for writing to output pin always use latch

sbit CF_RDY_direction at TRISD7_bit;
sbit CF_WE_direction  at TRISD6_bit;
sbit CF_OE_direction  at TRISD5_bit;
sbit CF_CD1_direction at TRISD4_bit;
sbit CF_CE1_direction at TRISD3_bit;
sbit CF_A2_direction  at TRISD2_bit;
sbit CF_A1_direction  at TRISD1_bit;
sbit CF_A0_direction  at TRISD0_bit;
// end of cf pinout

unsigned i;
char error;

void main() {
  PORTB = 0xFF;               // For monitoring progress
  TRISB = 0;
  Delay_ms(1000);

  Cf_Init();                  // Initialize CF ports
  while (!Cf_Detect()) ;      // Loop until CF card is initialized

  PORTB = 0x0F;
  Delay_ms(1000);

  error = 0;
  Cf_Read_Init(590, 1);       // Initialize CF read from sector address 590

  for (i = 0; i < 200; i++) {
     PORTB = Cf_Read_Byte();  // Read byte from CF card
     Delay_ms(10);
     if (PORTB != i) error = 1;
  }

  PORTB = 0xFF;
  Delay_ms(1000);
  PORTB = error;
}