/* Project name:
     CF_Read (Demonstration of Compact Flash Library usage)
 * Copyright:
     (c) MikroElektronika, 2011.
 * Revision History
     - Initial release;
     20110304(TL):
     - Adapted for PRO compilers;
 * Description:
     This project demonstrates usage of the Compact Flash Library routines,
     to access and raed from the CF (Compact Flash Card) storage media.
     Upon initialization, this example reads data from the sector 590 of the
     CF card. The readings are sent to UART.
 * Test configuration:

     MCU:             P32MX460F512L
                      http://ww1.microchip.com/downloads/en/DeviceDoc/61143G.pdf
     Dev.Board:       LV32MX v6
                      http://www.mikroe.com/eng/products/view/462/lv-32mx-v6-development-system/
     Oscillator:      XT-PLL, 80.000MHz
     Ext. Modules:    mE  ac:Compact_Flash_Board on PORTD(Control) and PORTE(Data)
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
     SW:              mikroC PRO for PIC32
                      http://www.mikroe.com/eng/products/view/623/mikroc-pro-for-pic32/

 * NOTES:
     - RS232 jumpers set to Rx = RF2 and Tx = RF8
     - PORTD (CF ctrl), PORTE (CF Data) LEDs = OFF
*/

// set compact flash pinout
char Cf_Data_Port at PORTE;

sbit CF_RDY at RD7_bit;
sbit CF_WE  at LATD6_bit;  // for writing to output pin always use latch
sbit CF_OE  at LATD5_bit;  // for writing to output pin always use latch
sbit CF_CD1 at RD4_bit;
sbit CF_CE1 at LATD3_bit;  // for writing to output pin always use latch
sbit CF_A2  at LATD2_bit;  // for writing to output pin always use latch
sbit CF_A1  at LATD1_bit;  // for writing to output pin always use latch
sbit CF_A0  at LATD0_bit;  // for writing to output pin always use latch

sbit CF_RDY_direction at TRISD7_bit;
sbit CF_WE_direction  at TRISD6_bit;
sbit CF_OE_direction  at TRISD5_bit;
sbit CF_CD1_direction at TRISD4_bit;
sbit CF_CE1_direction at TRISD3_bit;
sbit CF_A2_direction  at TRISD2_bit;
sbit CF_A1_direction  at TRISD1_bit;
sbit CF_A0_direction  at TRISD0_bit;
// end of cf pinout

const LINE_LEN = 39;
char file_contents[LINE_LEN] = "XX CF FAT16 library by Anton Rieckert\n";
char           filename[14] = "MIKRO00x.TXT";          // File names
unsigned short loop, loop2;
unsigned long  i, size;

void M_Create_Multiple_Files() {
  for(loop2 = 'B'; loop2 <= 'Z'; loop2++) {
    UART1_Write(loop2);                                // signal the progress
    filename[7] = loop2;                               // set filename
    Cf_Fat_Set_File_Date(2005,6,21,10,35,0);           // Set file date & time info
    Cf_Fat_Assign(&filename, 0xA0);                    // find existing file or create a new one
    Cf_Fat_Rewrite();                                  // To clear file and start with new data
    for(loop = 1; loop <= 44; loop++) {
      file_contents[0] = loop / 10 + 48;
      file_contents[1] = loop % 10 + 48;
      Cf_Fat_Write(file_contents, LINE_LEN-1);         // write data to the assigned file
    }
  }
}
void main() {
  AD1PCFG = 0xFFFF;                      // disable A/D inputs

  // Initialize UART1 module
  UART1_Init(56000);
  Delay_ms(100);

  UART1_Write_Text("Start");
  UART1_Write(13);
  UART1_Write(10);
  Delay_ms(100);

  // use fat16 quick format instead of init routine if a formatting is needed
  if (Cf_Fat_Init() == 0) {
    Delay_ms(2000);
  M_Create_Multiple_Files();
}
}