/* Project name:
     CF_Detect (Demonstration of Compact Flash Library usage)
 * Copyright:
     (c) MikroElektronika, 2010.
 * Revision History
     2006:
     - Initial release;
     20101130(TL):
     - Adapted for PRO compilers;
 * Description:
     This project demonstrates usage of the Compact Flash Library routines,
     to detect CF (Compact Flash Card) storage media.
 * Test configuration:
     
     MCU:             dsPIC30F6014A
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70566A.pdf
     Dev.Board:       BIGdsPIC6
                      http://www.mikroe.com/eng/products/view/483/bigdspic6-development-system/
     Oscillator:      HS-PLL 8x, 80.000 MHz
     Ext. Modules:    ac:Compact_Flash_Board
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
     SW:              mikroC PRO for dsPIC
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
         
 * NOTES:
     - PortD High(CF ctrl), PortF(CF Data), LEDs = Off
*/

// set compact flash pinout
char Cf_Data_Port at PORTF;

sbit CF_RDY at LATD15_bit;
sbit CF_WE  at LATD14_bit;
sbit CF_OE  at LATD13_bit;
sbit CF_CD1 at LATD12_bit;
sbit CF_CE1 at LATD11_bit;
sbit CF_A2  at LATD10_bit;
sbit CF_A1  at LATD9_bit;
sbit CF_A0  at LATD8_bit;

sbit CF_RDY_direction at TRISD15_bit;
sbit CF_WE_direction  at TRISD14_bit;
sbit CF_OE_direction  at TRISD13_bit;
sbit CF_CD1_direction at TRISD12_bit;
sbit CF_CE1_direction at TRISD11_bit;
sbit CF_A2_direction  at TRISD10_bit;
sbit CF_A1_direction  at TRISD9_bit;
sbit CF_A0_direction  at TRISD8_bit;
// end of cf pinout

void main() {
  ADPCFG = 0xFFFF;
  
  UART1_Init(56000);
  Delay_ms(100);

  UART1_Write_Text("Start");
  UART1_Write_Text(13);
  UART1_Write_Text(10);

  Cf_Init();    // Initialize CF ports
  while (1) {
     if (Cf_Detect())
        UART1_Write_Text("Detected");
     else
        UART1_Write_Text("Not Detected");

       Delay_ms(1000);
  }
}