/* Project name:
     CF_Read (Demonstration of Compact Flash Library usage)
 * Copyright:
     (c) MikroElektronika, 2010.
 * Revision History
     2006:
     - Initial release;
     20101130(TL):
     - Adapted for PRO compilers;
 * Description:
     This project demonstrates usage of the Compact Flash Library routines,
     to access and raed from the CF (Compact Flash Card) storage media.
     Upon initialization, this example reads some data from the CF card.
     The reading progress can be monitored on portC LEDs.
 * Test configuration:
     
     MCU:             dsPIC30F6014A
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70566A.pdf
     Dev.Board:       BIGdsPIC6
                      http://www.mikroe.com/eng/products/view/483/bigdspic6-development-system/
     Oscillator:      HS-PLL 8x, 80.000 MHz
     Ext. Modules:    ac:Compact_Flash_Board
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
     SW:              mikroC PRO for dsPIC
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
         
 * NOTES:
     - PortD(CF ctrl), PortF(CF Data), LEDs = OFF
     - PORTB LEDs switch = ON (for monitoring progress)
*/

// set compact flash pinout
char Cf_Data_Port at PORTF;

sbit CF_RDY at RD7_bit;
sbit CF_WE  at RD6_bit;
sbit CF_OE  at RD5_bit;
sbit CF_CD1 at RD4_bit;
sbit CF_CE1 at RD3_bit;
sbit CF_A2  at RD2_bit;
sbit CF_A1  at RD1_bit;
sbit CF_A0  at RD0_bit;

sbit CF_RDY_direction at TRISD7_bit;
sbit CF_WE_direction  at TRISD6_bit;
sbit CF_OE_direction  at TRISD5_bit;
sbit CF_CD1_direction at TRISD4_bit;
sbit CF_CE1_direction at TRISD3_bit;
sbit CF_A2_direction  at TRISD2_bit;
sbit CF_A1_direction  at TRISD1_bit;
sbit CF_A0_direction  at TRISD0_bit;
// end of cf pinout

unsigned i;
char error;

void main() {
  PORTB = 0xFF;               // For monitoring progress
  TRISB = 0;
  Delay_ms(1000);

  Cf_Init();                  // Initialize CF ports
  while (!Cf_Detect()) ;      // Loop until CF card is initialized

  PORTB = 0x0F;
  Delay_ms(1000);

  error = 0;
  Cf_Read_Init(590, 1);       // Initialize CF read from sector address 590

  for (i = 0; i < 200; i++) {
     PORTB = Cf_Read_Byte();  // Read byte from CF card
     Delay_ms(10);
     if (PORTB != i) error = 1;
  }

  PORTB = 0xFF;
  Delay_ms(1000);
  PORTB = error;
}