/* Project name:
     CF_Read (Demonstration of Compact Flash Library usage)
 * Copyright:
     (c) MikroElektronika, 2010.
 * Revision History
     2006:
     - Initial release;
     20101130(TL):
     - Adapted for PRO compilers;
 * Description:
     This project demonstrates usage of the Compact Flash Library routines,
     to access and raed from the CF (Compact Flash Card) storage media.
     Upon initialization, this example reads data from the sector 590 of the
     CF card. The readings are sent to UART.
 * Test configuration:
     
     MCU:             dsPIC30F6014A
                      http://ww1.microchip.com/downloads/en/DeviceDoc/70566A.pdf
     Dev.Board:       BIGdsPIC6
                      http://www.mikroe.com/eng/products/view/483/bigdspic6-development-system/
     Oscillator:      HS-PLL 8x, 80.000 MHz
     Ext. Modules:    ac:Compact_Flash_Board
                      http://www.mikroe.com/eng/products/view/131/compact-flash-board/
     SW:              mikroC PRO for dsPIC
                      http://www.mikroe.com/eng/products/view/231/mikroc-pro-for-dspic30-33-and-pic24/
         
 * NOTES:
     - RS232 jumpers set to Rx = RF2 and Tx = RF3
     - PORTD (CF ctrl), PORTB (CF Data) LEDs = OFF
*/

// set compact flash pinout
char Cf_Data_Port at PORTD;

sbit CF_RDY at RB7_bit;
sbit CF_WE  at LATB6_bit;  // for writing to output pin always use latch
sbit CF_OE  at LATB5_bit;  // for writing to output pin always use latch
sbit CF_CD1 at RB4_bit;
sbit CF_CE1 at LATB3_bit;  // for writing to output pin always use latch
sbit CF_A2  at LATB2_bit;  // for writing to output pin always use latch
sbit CF_A1  at LATB1_bit;  // for writing to output pin always use latch
sbit CF_A0  at LATB0_bit;  // for writing to output pin always use latch

sbit CF_RDY_direction at TRISB7_bit;
sbit CF_WE_direction  at TRISB6_bit;
sbit CF_OE_direction  at TRISB5_bit;
sbit CF_CD1_direction at TRISB4_bit;
sbit CF_CE1_direction at TRISB3_bit;
sbit CF_A2_direction  at TRISB2_bit;
sbit CF_A1_direction  at TRISB1_bit;
sbit CF_A0_direction  at TRISB0_bit;
// end of cf pinout

const LINE_LEN = 39;
char file_contents[LINE_LEN] = "XX CF FAT16 library by Anton Rieckert\n";
char           filename[14] = "MIKRO00x.TXT";          // File names
unsigned short loop, loop2;
unsigned long  i, size;

void M_Create_Multiple_Files() {
  for(loop2 = 'B'; loop2 <= 'Z'; loop2++) {
    UART1_Write(loop2);                                // signal the progress
    filename[7] = loop2;                               // set filename
    Cf_Fat_Set_File_Date(2005,6,21,10,35,0);           // Set file date & time info
    Cf_Fat_Assign(&filename, 0xA0);                    // find existing file or create a new one
    Cf_Fat_Rewrite();                                  // To clear file and start with new data
    for(loop = 1; loop <= 44; loop++) {
      file_contents[0] = loop / 10 + 48;
      file_contents[1] = loop % 10 + 48;
      Cf_Fat_Write(file_contents, LINE_LEN-1);         // write data to the assigned file
    }
  }
}
void main() {
  ADPCFG = 0xFFFF;                      // disable A/D inputs

  // Initialize UART1 module
  UART1_Init(19200);
  Delay_ms(10);

  // use fat16 quick format instead of init routine if a formatting is needed
  if (Cf_Fat_Init() == 0) {
    Delay_ms(2000);
  M_Create_Multiple_Files();
}
}